@@ -17,6 +17,11 @@
 #include <caml/custom.h>
 #include <caml/signals.h>
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+/* else attempt without (think msvc build) */
+#endif
+
 /* MySQL API */
 
 #if defined(_WIN32)
@@ -26,13 +31,12 @@
 #else
 #include <my_global.h>
 #endif
-#include <mysql.h>
-#else
+#endif
+
+#if defined(HAVE_MYSQL_MYSQL_H)
 #include <mysql/mysql.h>
-/*
-#include <mysql/mysqld_error.h>
-#include <mysql/errmsg.h>
-*/
+#else
+#include <mysql.h>
 #endif
 
 #define EXTERNAL                /* dummy to highlight fn's exported to ML */
@@ -186,6 +190,7 @@ static unsigned int ml_mysql_protocol_type[] = {
 #define SET_OPTION_BOOL(option) option_bool = Bool_val(v); SET_OPTION(option, &option_bool)
 #define SET_OPTION_INT(option) option_int = Int_val(v); SET_OPTION(option, &option_int)
 #define SET_OPTION_STR(option) SET_OPTION(option, String_val(v))
+#define SET_CLIENT_FLAG(flag) client_flag |= flag; break
 
 EXTERNAL value
 db_connect(value options, value args)
@@ -203,6 +208,7 @@ db_connect(value options, value args)
   MYSQL *mysql;
   unsigned int option_int;
   my_bool option_bool;
+  unsigned long client_flag = 0;
 
   init = mysql_init(NULL);
   if (!init) 
@@ -243,6 +249,7 @@ db_connect(value options, value args)
         {
           case 0: SET_OPTION(OPT_COMPRESS, NULL);
           case 1: SET_OPTION(OPT_NAMED_PIPE, NULL);
+          case 2: SET_CLIENT_FLAG(CLIENT_FOUND_ROWS);
           default: invalid_argument("Mysql.connect: unknown option");
         }
       }
@@ -259,7 +266,7 @@ db_connect(value options, value args)
     caml_enter_blocking_section();
     mysql = mysql_real_connect(init ,host ,user
                                ,pwd ,db ,port
-                               ,socket, 0);
+                               ,socket, client_flag);
     caml_leave_blocking_section();
 
     free(host); free(db); free(pwd); free(user); free(socket);
